#include <XSUser/Python/PyPlot.h>

#include <XSContainer.h>
#include <XSPlot/Plot/PlotDirector.h>
#include <XSUser/Global/XSGlobal.h>
#include <XSUtil/Parse/XSparse.h>

// Python 2.5 and later defines a type Py_ssize_t.
// Prior to that must use int.
#define PY_SZ_TYPE int


PyObject*
_pyXspec_setDevice(PyObject *self, PyObject *args)
{
   const char *devStr=0;
   if (!PyArg_ParseTuple(args, "z", &devStr))
      return NULL;
   if (XSparse::isBlank(devStr))
   {
      string msg("Error: Plotting device name is required.");
      PyErr_SetString(PyExc_Exception, msg.c_str());
      return NULL;
   }
   
   string deviceName(devStr);
   try
   {
      XSContainer::plot->setPlottingDevice(deviceName, true);
   }
   catch (...)
   {
      string msg("Unable to set plot device to: ");
      msg += deviceName;
      PyErr_SetString(PyExc_Exception, msg.c_str());
      return NULL;
   }
   return Py_BuildValue("i",0);
}

PyObject*
_pyXspec_doPlot(PyObject *self, PyObject *args)
{
   PY_SZ_TYPE nArgs = PySequence_Size(args);
   std::vector<string> plotComs;
   for (PY_SZ_TYPE i=0; i<nArgs; ++i)
   {
      PyObject* pyStr = PyTuple_GetItem(args, i);
      const char* plotCstr = PyString_AsString(pyStr);
      plotComs.push_back(string(plotCstr));      
   }
   try
   {
      XSGlobal::commonPlotHandler(plotComs, false);
   }
   catch (...)
   {
      PyErr_SetString(PyExc_Exception, "");
      return NULL;
   }
   return Py_BuildValue("i",0);
}
